/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef DUALCOUNT_H
#define DUALCOUNT_H

#include <string>

#include "controllers/common/acquisition/KineticCount.h"
#include "controllers/common/acquisition/mode/TimeAcquisitionController.h"

namespace cadarache {

class DualCount: public acquisition::KineticCount {

public:

	//! Type of controller
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of controller
	 */
	DualCount(const std::string& name);

	virtual void postConfiguration();

protected:

	virtual void stop();

private:

	virtual void preStart();
	virtual void gateStart();
	virtual void gateSynchro();

	virtual void pause();
	virtual void resume();

    ControllerPtr<acquisition::TimeAcquisitionController> m_DPPTimeGate;

};

}

#endif // KINETICCOUNT_H
