/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

/*!
 * \brief class cyclops camera data settings
 * \author J. Locatelli
 * \date 21-11-2019
 */

#ifndef CYCLOPSDATAPATH_H
#define CYCLOPSDATAPATH_H

#include <Controller.h>
#include "controllers/common/acquisition/ExperimentData.h"

#include "drivers/photonic/psl/PslDriver.h"

namespace cyclops {

/*!
 * \class cyclops data server path setiing
 * \brief Configure data path and name for cyclops data server
 */
class CyclopsDataPath: public ExperimentController, public controller::Start {

public:

	//! Type of controller
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the experiment controller
	 */
	CyclopsDataPath(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~CyclopsDataPath();

	/*!
	 * Properties
	 */
	Property<std::string> dataname;
	Property<std::string> datapath;

private:

	/*!
	 * \brief Method called before changing the property value
	 * This method is called after setting configuration during the creation of controller.
	 */
	virtual void postConfiguration();

	/*!
	 * \brief Start command
	 */
	virtual void start();

	void updateNumor();

	DriverPtr<psl::PslDriver> m_CamDriver;
	ControllerPtr<acquisition::ExperimentData> m_Title;

	/*!
	 * \brief implement unitary test
	 */
	virtual void test();

};

}

#endif //CYCLOPSDATAPATH_H
