/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef SRC_CONTROLLERS_LSS_D22SPECIAL_SPECTROSAMPLESEQUENCER_H_
#define SRC_CONTROLLERS_LSS_D22SPECIAL_SPECTROSAMPLESEQUENCER_H_

#include <Controller.h>
#include "controllers/lss/common/SampleSequencer.h"
#include "CountWithSpectro.h"
#include "controllers/spectrometer/QE65000Controller.h"

namespace d22special {

class SpectroSampleSequencer: public lss::SampleSequencer {

public:

	static const std::string TYPE;

	SpectroSampleSequencer(const std::string& name);
	SpectroSampleSequencer(const SpectroSampleSequencer& controller);

	virtual ~SpectroSampleSequencer();

	Property<bool> useCountWithSpectro;
	Property<int32> integrationTime;
	Property<int32> scansToAverage;

	ArrayProperty<float64> spectrumDataForActualSlot;

	virtual void setEnabledForLoading(bool all, bool postconf = true);
	virtual void setDisabled(bool all = false);

protected:
	virtual void start();
	virtual void stop();
	virtual void pause();
	virtual void resume();
	virtual void postConfiguration();

private:
	ControllerPtr<QE65000Controller> spectro;

	void startUsingCountWithSpectro();
	void stopUsingCountWithSpectro();
	void pauseUsingCountWithSpectro();
	void resumeUsingCountWithSpectro();

	void updateIntegrationTime();
	void updateScansToAverage();

	void startSpectroAndCount();
	void startCount();
	void startSpectro();

	void obtainSlotsAndActions();
	bool checkPositionIsHasNotBeenAlreadyMeasured(int32 slotPositionMinusTwo);
	void storeSpectrum(int32 executionLine);
	void appendSpectrumInDataFile();

	bool m_CountStarted;
	bool m_ChangerStarted;

	float64* m_yDataArray;
	std::map<int32, float64*> m_spectrum; // key = slot execution line/index, value = chromato
	std::map<int32, int32> m_numors; // key = slot execution line/index, value = numor of SANS measure done in specific slot index
	std::map<int32, std::list<std::pair<int32, int32>>> m_executionOrder;

	static const int32 ONLY_SPECTRO;
	static const int32 ONLY_SANS;
	static const int32 BOTH_SANS_SPECTRO;

};

}

#endif /* SRC_CONTROLLERS_LSS_D22SPECIAL_SPECTROSAMPLESEQUENCER_H_ */
