/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef NOMAD3D_NOMAD3DCONTROLLER_H
#define NOMAD3D_NOMAD3DCONTROLLER_H

#include "controllers/common/axis/AxisController.h"
#include "controllers/common/axis/VirtualAxisController.h"
#include <rapidjson/stringbuffer.h>
#include <cameo/cameo.h>
#include <memory>
#include <utility>
#include <thread>
#include <atomic>

namespace nomad3d {

/**
 * Class defining a controller for Nomad3D. The positions passed to the client integrate the offset.
 */
class Nomad3DController : public ExperimentController, public controller::Init {

public:
	//! Type of controller
	static const std::string TYPE;

	Nomad3DController(const std::string& name);
	Nomad3DController(const Nomad3DController& controller);
	virtual ~Nomad3DController();

	virtual void postConfiguration();
	virtual void init();

	void updateActualPosition(int32 i);

private:
	void periodicUpdate();
	void executionLoop();
	static double getUnitCoef(const std::string& unit);

	struct AxisControllerData {
		axis::AxisController* controller;
		std::string name;
		double coef;
	};

	std::vector<AxisControllerData> m_axisControllers;

	struct VirtualAxisControllerData {
		axis::VirtualAxisController* controller;
		std::string name;
		double coef;
	};

	std::vector<VirtualAxisControllerData> m_virtualAxisControllers;

	Property<std::string> axisPositions;
	rapidjson::StringBuffer s;

	std::atomic<bool> m_running;

	std::unique_ptr<cameo::application::Publisher> m_positionPublisher;
	std::mutex m_publisherMutex;

	std::unique_ptr<std::thread> m_periodicUpdateThread;

	std::unique_ptr<cameo::application::Responder> m_executionResponder;
	std::unique_ptr<std::thread> m_executionResponderThread;
};

}

#endif
