/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENPKSCONTROLLER_H
#define CAENPKSCONTROLLER_H

#include <Controller.h>

#include "drivers/caen/caen_pks/CAENPksDriver.h"

namespace npp {

/*!
 * \class CAENVPhaDriver
 * \brief Main class for the CAENPhaDriver device driver
 *
 * \par
 * Class for CAENPhaDriver driver. Implements DeviceDriver methods.
 * \par
 * The CAENPhaDriver device manages the global functionality of the
 * CAEN V1724 and CAEN V1730 VME Digitizers.
 */


class CAENPksController: public ExperimentController {

public:

	//! Driver type value
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the device driver
	 */
	CAENPksController(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~CAENPksController();

	/**
	 * \brief Postconfiguration
	 */
	virtual void postConfiguration();

	// Channels properties
	Property<int32> nbChannels;
	DynamicProperty<int32> channelsActive;
	DynamicProperty<int32> triggerThreshold;

private:

	DriverPtr<caen_pks::CAENPksDriver> m_adcDriver;

	void refreshChannelsActiveProperty(int32 index, int32 aValue) throw (CannotSetValue);
	void refreshTriggerThresholdProperty(int32 index, int32 aValue) throw (CannotSetValue);

	void writeParam();
};

}
#endif //CAENPKSCONTROLLER_H
