/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "RealCAENPksDriver.h"

#include <controllers/common/acquisition/mode/DPPAcquisitionCommon.h>
#include "CAENPksDriver.h"

using namespace std;
using namespace driver;

namespace caen_pks {

/*
 * Constructor
 */
RealCAENPksDriver::RealCAENPksDriver(CAENPksDriver* owner) :
	CAENPksState(owner) {

}

/*
 * Destructor
 */
RealCAENPksDriver::~RealCAENPksDriver() {

}

/*!
 * \brief Init command implementation
 */
void RealCAENPksDriver::init() {

	reset();

	readInfos();

	writeParam();
}

/*!
 * \brief Clear command implementation
 */
void RealCAENPksDriver::clear() {

	uint16 value = 0;
	owner()->read(PKS_BIT2SET_REG, Vme::WORD_WIDTH, 1, (void*) &value);
	cout << "value out: 0x" << hex << value << dec << endl;
	value = value | (1<<2);
	cout << "value in: 0x" << hex << value << dec << endl;
	owner()->write(PKS_BIT2SET_REG, Vme::WORD_WIDTH, 1, (void*) &value);
	value = 1<<2;
	owner()->write(PKS_BIT2CLR_REG, Vme::WORD_WIDTH, 1, (void*) &value);
}

/*!
 * \brief Reset command implementation
 */
void RealCAENPksDriver::reset() {

	clear();
}

/*!
 * \brief Write Param command implementation
 */
void RealCAENPksDriver::writeParam() {
	// Write threshold and active flag
	for (int32 index=0; index<owner()->nbChannels(); ++index) {
		uint32 adrs = PKS_THRESHOLD_REG + (PKS_CHANNEL_INCREMENT * index);
		uint16 value = owner()->triggerThreshold.get(index);
		if (owner()->channelActive.get(index) == 0) {
			value += 1<<8;
		}
		owner()->write(adrs, Vme::WORD_WIDTH, 1, (void*) &value);
	}
}

/*!
 * \brief Read Infos command implementation
 */
void RealCAENPksDriver::readInfos() {

	uint16 value = 0;
	owner()->read(PKS_FIRMWARE_REG, Vme::WORD_WIDTH, 1, (void*) &value);
	owner()->firmware = value;
	value = 0;
	owner()->read(PKS_VERSION_REG, Vme::WORD_WIDTH, 1, (void*) &value);
	owner()->model = value;
}

}
