/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENSY2527DRIVER_H
#define CAENSY2527DRIVER_H

#include <Driver.h>
#include "drivers/global/sockettcp/SocketTcp.h"

#include "CAENSy2527BoardDriver.h"

namespace caen_sy2527 {

/*!
 * \class CAENSy2527Driver
 * \brief Main class for the CAENSy2527Driver device driver
 *
 * \par
 * Class for CAENSy2527Driver driver. Implements DeviceDriver methods.
 * \par
 * The CAENSy2527Driver device manages the global functionality of the CAEN SY2527 HV power supply.
 */

class CAENSy2527Driver : public driver::SocketTcp {

public:

	//! Driver type value
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the device driver
	 */
	CAENSy2527Driver(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~CAENSy2527Driver();

	/*!
	 * \brief Method called for executing a command
	 *
	 * \param[in] command the command to apply on the controller
	 */
	virtual void execute(const std::string& aCommand);

	void start(CAENSy2527BoardDriver* aBoard);

	void stop(CAENSy2527BoardDriver* aBoard);

	void read(CAENSy2527BoardDriver* aBoard);

	void readParam(CAENSy2527BoardDriver* aBoard);

	void writeParam(CAENSy2527BoardDriver* aBoard);

	void readStatus(CAENSy2527BoardDriver* aBoard);

	void powerOn(CAENSy2527BoardDriver* aBoard);

	void powerOff(CAENSy2527BoardDriver* aBoard);

	Property<std::string> crateModel;
	Property<std::string> linkType;
	Property<int32> nbSlots;

	// Crate properties
	DynamicProperty<int32> 		 channelsPerBoard;
	DynamicProperty<int32> 		 boardSerial;
	DynamicProperty<std::string> boardModel;
	DynamicProperty<std::string> boardDescription;
	DynamicProperty<std::string> boardFirmware;

	int32 m_crateHandle;
};

}
#endif //CAENSY2527DRIVER_H
