/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENSYx527STATE_H
#define CAENSYx527STATE_H

#include <Driver.h>

#include "CAENSYx527Driver.h"

namespace caen_syx527 {

/*!
 * \class CAENSYx527State
 * \brief Implements State pattern
 */
class CAENSYx527State: public DriverState<CAENSYx527Driver> {

public:

	/*!
	 * \brief Constructor.
	 */
	CAENSYx527State(CAENSYx527Driver* owner) :
		DriverState<CAENSYx527Driver> (owner) {
	}

	/*!
	 * \brief Destructor.
	 */
	virtual ~CAENSYx527State() {
	}

	/*!
	 * \brief Init
	 */
	virtual void init() = 0;

	/*!
	 * \brief Read parameters.
	 */
	virtual void readParamChannels() = 0;

	/*!
	 * \brief Write parameters.
	 */
	virtual void writeParam(int iChannel,std::string Param,float value) = 0;

	/*!
	 * \brief Power on.
	 */
	virtual void powerOn(int iChannel) = 0;

	/*!
	 * \brief Power off.
	 */
	virtual void powerOff(int iChannel) = 0;

};

}

#endif //CAENSYx527STATE_H
